﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.InteropServices;
using System.Security.Cryptography.X509Certificates;
using System.Security.Principal;
using System.Text;

namespace SVMctl_I2C_CSharp
{
    /// <summary>
    /// 接続ボード情報の格納用クラス
    /// </summary>
    public class BoardInformation
    {
        #region ▼ Property
        /// <summary>
        /// デバイスIDを取得または設定します。
        /// </summary>
        public int DeviceId
        {
            get; set;
        }

        /// <summary>
        /// 基板種別を取得または設定します。
        /// </summary>
        /// <remarks>0..SVM, SVIシリーズ、1..SVOシリーズ</remarks>
        public int BoardType
        {
            get; set;
        }

        /// <summary>
        /// 基板名を取得または設定します。
        /// </summary>
        public string BoardName
        {
            get; set;
        }

        /// <summary>
        /// 基板表示名を取得または設定します。
        /// </summary>
        public string BoardInfo
        {
            get; set;
        }
        
        /// <summary>
        /// 基板・FW識別コードであるカスタムコードを格納します。
        /// </summary>
        public FWInfo FwInfo{
            get;set;
        }
        
        /// <summary>
        /// ボードIDを取得または設定します。
        /// </summary>
        public int BoardId
        {
            get; set;
        }

        /// <summary>
        /// この基板がUSB3.0で接続されているかどうかを取得または設定します。
        /// </summary>
        /// <remarks>true..この基板はUSB3.0で接続されています、false..この基板はUSB3.0で接続されていません</remarks>
        public bool IsUSB3
        {
            get; set;
        }

        
        #endregion
    }
    
    public class FWInfo {
        public int Revision{
            get; set;
        } 
        public byte FWVersion{
            get; set;
        }
        public byte FpgaVersion {
            get; set;
        }
        public byte FpgaVersion2 {
            get; set;
        }
        
        public string CustomCode{
            get;set;
        }
        
        public FWInfo(int revision, byte fwVersion, byte fpgaVersion, byte fpgaVersion2, string customCode){
            Revision = revision;
            FWVersion = fwVersion;
            FpgaVersion = fpgaVersion;
            FpgaVersion2 = fpgaVersion2;
            CustomCode = customCode;
        }
        public FWInfo(){
            Revision = -1;
            FWVersion = new byte();
            FpgaVersion = new byte();
            FpgaVersion2 = new byte();
            CustomCode = "";
        }
        
    }
}
